==> marketplace-constants-0.1.3.tar.gz: marketplace-constants-0.1.3/mpconstants/regions/ta_LK.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'U.A.E.',
 u'af': u'Afghanistan',
 u'ag': u'Antigua and Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Netherlands Antilles',
 u'ao': u'Angola',
 u'aq': u'Antarctica',
 u'ar': u'Argentina',
 u'as': u'American Samoa',
 u'at': u'Austria',
 u'au': u'\u0b85\u0bb5\u0bc1\u0bb8\u0bcd\u0bb0\u0bc7\u0bb2\u0bbf\u0baf\u0bbe',
 u'aw': u'Aruba',
 u'ax': u'\\u00c5land Islands',
 u'az': u'Azerbaijan',
 u'ba': u'Bosnia and Herzegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'\u0baa\u0bc6\u0bb2\u0bcd\u0b9c\u0bbf\u0baf\u0bae\u0bcd',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrain',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\\u00e9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'\u0baa\u0bbf\u0bb1\u0bc7\u0b9a\u0bbf\u0bb2\u0bcd',
 u'bs': u'Bahamas',
 u'bt': u'Bhutan',
 u'bv': u'Bouvet Island',
 u'bw': u'Botswana',
 u'by': u'Belarus',
 u'bz': u'Belize',
 u'ca': u'Canada',
 u'cc': u'Cocos (Keeling) Islands',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Central African Republic',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Switzerland',
 u'ci': u'Ivory Coast',
 u'ck': u'Cook Islands',
 u'cl': u'Chile',
 u'cm': u'Cameroon',
 u'cn': u'\u0b9a\u0bc0\u0ba9\u0bbe',
 u'co': u'\u0b95\u0bc6\u0bb2\u0bae\u0bcd\u0baa\u0bbf\u0baf\u0bbe',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Cape Verde',
 u'cx': u'Christmas Island',
 u'cy': u'Cyprus',
 u'cz': u'Czech Republic',
 u'de': u'\u0b9c\u0bc7\u0bb0\u0bcd\u0bae\u0ba9\u0bbf',
 u'dj': u'Djibouti',
 u'dk': u'\u0b9f\u0bc6\u0ba9\u0bcd\u0bae\u0bbe\u0bb0\u0bcd\u0b95\u0bcd',
 u'dm': u'Dominica',
 u'do': u'Dominican Republic',
 u'dz': u'Algeria',
 u'ec': u'Ecuador',
 u'ee': u'Estonia',
 u'eg': u'\u0b8e\u0b95\u0bbf\u0baa\u0bcd\u0ba4\u0bc1',
 u'eh': u'Western Sahara',
 u'er': u'Eritrea',
 u'es': u'\u0bb8\u0bcd\u0baa\u0bc6\u0baf\u0bbf\u0ba9\u0bcd',
 u'et': u'Ethiopia',
 u'fi': u'Finland',
 u'fj': u'Fiji',
 u'fk': u'Falkland Islands (Malvinas)',
 u'fm': u'Micronesia',
 u'fo': u'Faroe Islands',
 u'fr': u'\u0baa\u0bbf\u0bb0\u0bbe\u0ba9\u0bcd\u0bb8\u0bcd',
 u'ga': u'Gabon',
 u'gb': u'\u0b87\u0b99\u0bcd\u0b95\u0bbf\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'French Guiana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Greenland',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Equatorial Guinea',
 u'gr': u'Greece',
 u'gs': u'South Georgia and the South Sandwich Islands',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard Island and McDonald Islands',
 u'hn': u'Honduras',
 u'hr': u'Croatia',
 u'ht': u'Haiti',
 u'hu': u'\u0b95\u0b99\u0bcd\u0b95\u0bc7\u0bb0\u0bbf',
 u'id': u'\u0b87\u0ba8\u0bcd\u0ba4\u0bcb\u0ba9\u0bbf\u0b9a\u0bbf\u0baf\u0bbe',
 u'ie': u'Ireland',
 u'il': u'Israel',
 u'im': u'Isle of Man',
 u'in': u'\u0b87\u0ba8\u0bcd\u0ba4\u0bbf\u0baf\u0bbe',
 u'io': u'British Indian Ocean Territory',
 u'iq': u'\u0b88\u0bb0\u0bbe\u0b95\u0bcd',
 u'ir': u'\u0b88\u0bb0\u0bbe\u0ba9\u0bcd',
 u'is': u'Iceland',
 u'it': u'\u0b87\u0ba4\u0bcd\u0ba4\u0bbe\u0bb2\u0bbf',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Jordan',
 u'jp': u'\u0baf\u0baa\u0bcd\u0baa\u0bbe\u0ba9\u0bcd',
 u'ke': u'\u0b95\u0bc6\u0ba9\u0bcd\u0baf\u0bbe',
 u'kg': u'Kyrgyzstan',
 u'kh': u'\u0b95\u0bae\u0bcd\u0baa\u0bc7\u0bbe\u0b9f\u0bbf\u0baf\u0bbe',
 u'ki': u'Kiribati',
 u'km': u'Comoros',
 u'kn': u'Saint Kitts and Nevis',
 u'kp': u'\u0bb5\u0b9f \u0b95\u0bc6\u0bb0\u0bbf\u0baf\u0bbe',
 u'kr': u'\u0ba4\u0bc6\u0ba9\u0bcd \u0b95\u0bc6\u0bb0\u0bbf\u0baf\u0bbe',
 u'kw': u'\u0b95\u0bc1\u0bb5\u0bc8\u0ba4\u0bcd',
 u'ky': u'Cayman Islands',
 u'kz': u'Kazakhstan',
 u'la': u'Laos',
 u'lb': u'Lebanon',
 u'lc': u'Saint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'\u0b87\u0bb2\u0b99\u0bcd\u0b95\u0bc8',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lithuania',
 u'lu': u'Luxembourg',
 u'lv': u'Latvia',
 u'ly': u'Libya',
 u'ma': u'Morocco',
 u'mc': u'Monaco',
 u'md': u'Moldova',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'\u0bae\u0b9f\u0b95\u0bb8\u0bcd\u0b95\u0bbe\u0bb0\u0bcd',
 u'mh': u'Marshall Islands',
 u'mk': u'Macedonia, F.Y.R. of',
 u'ml': u'Mali',
 u'mm': u'\u0bae\u0bbf\u0baf\u0bbe\u0ba9\u0bcd\u0bae\u0bbe\u0bb0\u0bcd',
 u'mn': u'Mongolia',
 u'mo': u'Macao',
 u'mp': u'Northern Mariana Islands',
 u'mq': u'Martinique',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'\u0bae\u0bbe\u0bb2\u0bc8\u0ba4\u0bc0\u0bb5\u0bc1',
 u'mw': u'Malawi',
 u'mx': u'Mexico',
 u'my': u'\u0bae\u0bb2\u0bc7\u0b9a\u0bbf\u0baf\u0bbe',
 u'mz': u'Mozambique',
 u'na': u'Namibia',
 u'nc': u'New Caledonia',
 u'ne': u'Niger',
 u'nf': u'Norfolk Island',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Netherlands',
 u'no': u'\u0ba8\u0bcb\u0bb0\u0bcd\u0bb5\u0bc7',
 u'np': u'\u0ba8\u0bc7\u0baa\u0bbe\u0bb3\u0bae\u0bcd',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'New Zealand',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'French Polynesia',
 u'pg': u'Papua New Guinea',
 u'ph': u'Philippines',
 u'pk': u'\u0baa\u0bbe\u0b95\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'pl': u'\u0baa\u0bcb\u0bb2\u0ba8\u0bcd\u0ba4\u0bc1',
 u'pm': u'Saint Pierre and Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Rico',
 u'ps': u'Occupied Palestinian Territory',
 u'pt': u'\u0baa\u0bcb\u0bb0\u0bcd\u0ba4\u0bcd\u0ba4\u0bc1\u0b95\u0bcd\u0b95\u0bb2\u0bcd',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'\u0b95\u0b9f\u0bcd\u0b9f\u0bbe\u0bb0\u0bcd',
 u're': u'Reunion',
 u'ro': u'Romania',
 u'rs': u'Serbia',
 u'ru': u'Russian Federation',
 u'rw': u'Rwanda',
 u'sa': u'\u0b9a\u0bb5\u0bc2\u0ba4\u0bbf \u0b85\u0bb0\u0bc7\u0baa\u0bbf\u0baf\u0bbe',
 u'sb': u'Solomon Islands',
 u'sc': u'Seychelles',
 u'sd': u'\u0b9a\u0bc1\u0b9f\u0bbe\u0ba9\u0bcd',
 u'se': u'\u0b9a\u0bc1\u0bb5\u0bc0\u0b9f\u0ba9\u0bcd',
 u'sg': u'\u0b9a\u0bbf\u0b99\u0bcd\u0b95\u0baa\u0bcd\u0baa\u0bc2\u0bb0\u0bcd',
 u'sh': u'Saint Helena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard and Jan Mayen',
 u'sk': u'Slovakia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'\u0b9a\u0bc7\u0bbe\u0bae\u0bbe\u0bb2\u0bbf\u0baf\u0bbe',
 u'sr': u'Suriname',
 u'st': u'Sao Tome and Principe',
 u'sv': u'El Salvador',
 u'sy': u'Syria',
 u'sz': u'Swaziland',
 u'tc': u'Turks and Caicos Islands',
 u'td': u'Chad',
 u'tf': u'French Southern Territories',
 u'tg': u'Togo',
 u'th': u'Thailand',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'\u0ba4\u0bc1\u0bb0\u0bc1\u0b95\u0bcd\u0b95\u0bbf',
 u'tt': u'Trinidad and Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'\u0ba4\u0bbe\u0baf\u0bcd\u0bb5\u0bbe\u0ba9\u0bcd',
 u'tz': u'Tanzania',
 u'ua': u'\u0b89\u0b95\u0bcd\u0b95\u0bbf\u0bb0\u0ba9\u0bcd',
 u'ug': u'Uganda',
 u'um': u'United States Minor Outlying Islands',
 u'us': u'\u0b85\u0bae\u0bc6\u0bb0\u0bbf\u0b95\u0bcd\u0b95\u0bbe',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'\u0bb5\u0ba4\u0bcd\u0ba4\u0bbf\u0b95\u0bcd\u0b95\u0bbe\u0ba9\u0bcd',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'Venezuela',
 u'vg': u'British Virgin Islands',
 u'vi': u'U.S. Virgin Islands',
 u'vn': u'\u0bb5\u0bbf\u0b9c\u0b9f\u0bcd\u0ba8\u0bbe\u0bae\u0bcd',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis and Futuna',
 u'ws': u'Samoa',
 u'ye': u'\u0b9c\u0bc7\u0bae\u0ba9\u0bcd',
 u'yt': u'Mayotte',
 u'za': u'\u0ba4\u0bc6\u0ba9\u0bcd \u0b86\u0baa\u0bbf\u0bb0\u0bbf\u0b95\u0bcd\u0b95\u0bbe',
 u'zm': u'Zambia',
 u'zw': u'\u0b9a\u0bbf\u0bae\u0bcd\u0baa\u0bbe\u0bb5\u0bc7'}

==> marketplace-constants-0.2.0.tar.gz: marketplace-constants-0.2.0/mpconstants/regions/ta_LK.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'U.A.E.',
 u'af': u'Afghanistan',
 u'ag': u'Antigua and Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Netherlands Antilles',
 u'ao': u'Angola',
 u'aq': u'Antarctica',
 u'ar': u'Argentina',
 u'as': u'American Samoa',
 u'at': u'Austria',
 u'au': u'\u0b85\u0bb5\u0bc1\u0bb8\u0bcd\u0bb0\u0bc7\u0bb2\u0bbf\u0baf\u0bbe',
 u'aw': u'Aruba',
 u'ax': u'\xc5land Islands',
 u'az': u'Azerbaijan',
 u'ba': u'Bosnia and Herzegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'\u0baa\u0bc6\u0bb2\u0bcd\u0b9c\u0bbf\u0baf\u0bae\u0bcd',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrain',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'\u0baa\u0bbf\u0bb1\u0bc7\u0b9a\u0bbf\u0bb2\u0bcd',
 u'bs': u'Bahamas',
 u'bt': u'Bhutan',
 u'bv': u'Bouvet Island',
 u'bw': u'Botswana',
 u'by': u'Belarus',
 u'bz': u'Belize',
 u'ca': u'Canada',
 u'cc': u'Cocos (Keeling) Islands',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Central African Republic',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Switzerland',
 u'ci': u'Ivory Coast',
 u'ck': u'Cook Islands',
 u'cl': u'Chile',
 u'cm': u'Cameroon',
 u'cn': u'\u0b9a\u0bc0\u0ba9\u0bbe',
 u'co': u'\u0b95\u0bc6\u0bb2\u0bae\u0bcd\u0baa\u0bbf\u0baf\u0bbe',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Cape Verde',
 u'cx': u'Christmas Island',
 u'cy': u'Cyprus',
 u'cz': u'Czech Republic',
 u'de': u'\u0b9c\u0bc7\u0bb0\u0bcd\u0bae\u0ba9\u0bbf',
 u'dj': u'Djibouti',
 u'dk': u'\u0b9f\u0bc6\u0ba9\u0bcd\u0bae\u0bbe\u0bb0\u0bcd\u0b95\u0bcd',
 u'dm': u'Dominica',
 u'do': u'Dominican Republic',
 u'dz': u'Algeria',
 u'ec': u'Ecuador',
 u'ee': u'Estonia',
 u'eg': u'\u0b8e\u0b95\u0bbf\u0baa\u0bcd\u0ba4\u0bc1',
 u'eh': u'Western Sahara',
 u'er': u'Eritrea',
 u'es': u'\u0bb8\u0bcd\u0baa\u0bc6\u0baf\u0bbf\u0ba9\u0bcd',
 u'et': u'Ethiopia',
 u'fi': u'Finland',
 u'fj': u'Fiji',
 u'fk': u'Falkland Islands (Malvinas)',
 u'fm': u'Micronesia',
 u'fo': u'Faroe Islands',
 u'fr': u'\u0baa\u0bbf\u0bb0\u0bbe\u0ba9\u0bcd\u0bb8\u0bcd',
 u'ga': u'Gabon',
 u'gb': u'\u0b87\u0b99\u0bcd\u0b95\u0bbf\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'French Guiana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Greenland',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Equatorial Guinea',
 u'gr': u'Greece',
 u'gs': u'South Georgia and the South Sandwich Islands',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard Island and McDonald Islands',
 u'hn': u'Honduras',
 u'hr': u'Croatia',
 u'ht': u'Haiti',
 u'hu': u'\u0b95\u0b99\u0bcd\u0b95\u0bc7\u0bb0\u0bbf',
 u'id': u'\u0b87\u0ba8\u0bcd\u0ba4\u0bcb\u0ba9\u0bbf\u0b9a\u0bbf\u0baf\u0bbe',
 u'ie': u'Ireland',
 u'il': u'Israel',
 u'im': u'Isle of Man',
 u'in': u'\u0b87\u0ba8\u0bcd\u0ba4\u0bbf\u0baf\u0bbe',
 u'io': u'British Indian Ocean Territory',
 u'iq': u'\u0b88\u0bb0\u0bbe\u0b95\u0bcd',
 u'ir': u'\u0b88\u0bb0\u0bbe\u0ba9\u0bcd',
 u'is': u'Iceland',
 u'it': u'\u0b87\u0ba4\u0bcd\u0ba4\u0bbe\u0bb2\u0bbf',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Jordan',
 u'jp': u'\u0baf\u0baa\u0bcd\u0baa\u0bbe\u0ba9\u0bcd',
 u'ke': u'\u0b95\u0bc6\u0ba9\u0bcd\u0baf\u0bbe',
 u'kg': u'Kyrgyzstan',
 u'kh': u'\u0b95\u0bae\u0bcd\u0baa\u0bc7\u0bbe\u0b9f\u0bbf\u0baf\u0bbe',
 u'ki': u'Kiribati',
 u'km': u'Comoros',
 u'kn': u'Saint Kitts and Nevis',
 u'kp': u'\u0bb5\u0b9f \u0b95\u0bc6\u0bb0\u0bbf\u0baf\u0bbe',
 u'kr': u'\u0ba4\u0bc6\u0ba9\u0bcd \u0b95\u0bc6\u0bb0\u0bbf\u0baf\u0bbe',
 u'kw': u'\u0b95\u0bc1\u0bb5\u0bc8\u0ba4\u0bcd',
 u'ky': u'Cayman Islands',
 u'kz': u'Kazakhstan',
 u'la': u'Laos',
 u'lb': u'Lebanon',
 u'lc': u'Saint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'\u0b87\u0bb2\u0b99\u0bcd\u0b95\u0bc8',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lithuania',
 u'lu': u'Luxembourg',
 u'lv': u'Latvia',
 u'ly': u'Libya',
 u'ma': u'Morocco',
 u'mc': u'Monaco',
 u'md': u'Moldova',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'\u0bae\u0b9f\u0b95\u0bb8\u0bcd\u0b95\u0bbe\u0bb0\u0bcd',
 u'mh': u'Marshall Islands',
 u'mk': u'Macedonia, F.Y.R. of',
 u'ml': u'Mali',
 u'mm': u'\u0bae\u0bbf\u0baf\u0bbe\u0ba9\u0bcd\u0bae\u0bbe\u0bb0\u0bcd',
 u'mn': u'Mongolia',
 u'mo': u'Macao',
 u'mp': u'Northern Mariana Islands',
 u'mq': u'Martinique',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'\u0bae\u0bbe\u0bb2\u0bc8\u0ba4\u0bc0\u0bb5\u0bc1',
 u'mw': u'Malawi',
 u'mx': u'Mexico',
 u'my': u'\u0bae\u0bb2\u0bc7\u0b9a\u0bbf\u0baf\u0bbe',
 u'mz': u'Mozambique',
 u'na': u'Namibia',
 u'nc': u'New Caledonia',
 u'ne': u'Niger',
 u'nf': u'Norfolk Island',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Netherlands',
 u'no': u'\u0ba8\u0bcb\u0bb0\u0bcd\u0bb5\u0bc7',
 u'np': u'\u0ba8\u0bc7\u0baa\u0bbe\u0bb3\u0bae\u0bcd',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'New Zealand',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'French Polynesia',
 u'pg': u'Papua New Guinea',
 u'ph': u'Philippines',
 u'pk': u'\u0baa\u0bbe\u0b95\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'pl': u'\u0baa\u0bcb\u0bb2\u0ba8\u0bcd\u0ba4\u0bc1',
 u'pm': u'Saint Pierre and Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Rico',
 u'ps': u'Occupied Palestinian Territory',
 u'pt': u'\u0baa\u0bcb\u0bb0\u0bcd\u0ba4\u0bcd\u0ba4\u0bc1\u0b95\u0bcd\u0b95\u0bb2\u0bcd',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'\u0b95\u0b9f\u0bcd\u0b9f\u0bbe\u0bb0\u0bcd',
 u're': u'Reunion',
 u'ro': u'Romania',
 u'rs': u'Serbia',
 u'ru': u'Russian Federation',
 u'rw': u'Rwanda',
 u'sa': u'\u0b9a\u0bb5\u0bc2\u0ba4\u0bbf \u0b85\u0bb0\u0bc7\u0baa\u0bbf\u0baf\u0bbe',
 u'sb': u'Solomon Islands',
 u'sc': u'Seychelles',
 u'sd': u'\u0b9a\u0bc1\u0b9f\u0bbe\u0ba9\u0bcd',
 u'se': u'\u0b9a\u0bc1\u0bb5\u0bc0\u0b9f\u0ba9\u0bcd',
 u'sg': u'\u0b9a\u0bbf\u0b99\u0bcd\u0b95\u0baa\u0bcd\u0baa\u0bc2\u0bb0\u0bcd',
 u'sh': u'Saint Helena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard and Jan Mayen',
 u'sk': u'Slovakia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'\u0b9a\u0bc7\u0bbe\u0bae\u0bbe\u0bb2\u0bbf\u0baf\u0bbe',
 u'sr': u'Suriname',
 u'st': u'Sao Tome and Principe',
 u'sv': u'El Salvador',
 u'sy': u'Syria',
 u'sz': u'Swaziland',
 u'tc': u'Turks and Caicos Islands',
 u'td': u'Chad',
 u'tf': u'French Southern Territories',
 u'tg': u'Togo',
 u'th': u'Thailand',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'\u0ba4\u0bc1\u0bb0\u0bc1\u0b95\u0bcd\u0b95\u0bbf',
 u'tt': u'Trinidad and Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'\u0ba4\u0bbe\u0baf\u0bcd\u0bb5\u0bbe\u0ba9\u0bcd',
 u'tz': u'Tanzania',
 u'ua': u'\u0b89\u0b95\u0bcd\u0b95\u0bbf\u0bb0\u0ba9\u0bcd',
 u'ug': u'Uganda',
 u'um': u'United States Minor Outlying Islands',
 u'us': u'\u0b85\u0bae\u0bc6\u0bb0\u0bbf\u0b95\u0bcd\u0b95\u0bbe',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'\u0bb5\u0ba4\u0bcd\u0ba4\u0bbf\u0b95\u0bcd\u0b95\u0bbe\u0ba9\u0bcd',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'Venezuela',
 u'vg': u'British Virgin Islands',
 u'vi': u'U.S. Virgin Islands',
 u'vn': u'\u0bb5\u0bbf\u0b9c\u0b9f\u0bcd\u0ba8\u0bbe\u0bae\u0bcd',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis and Futuna',
 u'ws': u'Samoa',
 u'ye': u'\u0b9c\u0bc7\u0bae\u0ba9\u0bcd',
 u'yt': u'Mayotte',
 u'za': u'\u0ba4\u0bc6\u0ba9\u0bcd \u0b86\u0baa\u0bbf\u0bb0\u0bbf\u0b95\u0bcd\u0b95\u0bbe',
 u'zm': u'Zambia',
 u'zw': u'\u0b9a\u0bbf\u0bae\u0bcd\u0baa\u0bbe\u0bb5\u0bc7'}
